#
# Copyright (c) 2002, 2003 Sam Leffler, Errno Consulting
# All rights reserved.
#
# Modifications for cifs vfs module are (c) 2003 Alexander Bokovoy, <ab@samba.org>
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer,
#    without modification.
# 2. Redistributions in binary form must reproduce at minimum a disclaimer
#    similar to the "NO WARRANTY" disclaimer below ("Disclaimer") and any
#    redistribution must be conditioned upon including a substantially
#    similar Disclaimer requirement for further binary redistribution.
# 3. Neither the names of the above-listed copyright holders nor the names
#    of any contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# Alternatively, this software may be distributed under the terms of the
# GNU General Public License ("GPL") version 2 as published by the Free
# Software Foundation.
#
# NO WARRANTY
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF NONINFRINGEMENT, MERCHANTIBILITY
# AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
# THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY,
# OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
# THE POSSIBILITY OF SUCH DAMAGES.
#
# $Id: Makefile.inc,v 1.16 2003/09/16 05:08:10 samleffler Exp $
#

DESTDIR=
#
# Compilation configuration for building i386-elf.
# This assumes the build platform is also i386-elf.
#

#
NM=		nm
AWK=		awk


#
# Set KERNEL_VERSION and KERNEL_PATH variables here or in the environment
# to build for a different kernel than the one currently running
#
#KERNEL_VERSION=	
#KERNEL_PATH=	

#
#
# Path to the Linux kernel, include files, and where to install the modules.
#
ifndef KERNEL_VERSION
KERNEL_VERSION=	$(shell uname -r)
endif
ifndef KERNEL_PATH
KERNEL_PATH=	/lib/modules/${KERNEL_VERSION}/build
endif
LINUX=		${KERNEL_PATH}/include
MODULE_PATH=	/lib/modules/${KERNEL_VERSION}/kernel/fs
#
# A numeric version of the target system's version string, suitable
# for doing if checks in make files.
#
ifndef LINUX_VERSION
LINUX_VERSION=	$(shell echo $(KERNEL_VERSION) | \
		awk '{ split($$0,a,"."); print a[1]*100+a[2]; }')
endif
#
# Basic build components.
#
COPTS=	-Wall -O2
CLEANFILES=	.depend

include ${KERNEL_PATH}/.config

ifdef CONFIG_SMP
COPTS+=	-D__SMP__ -DSMP
endif

ifndef CONFIG_FRAME_POINTER
COPTS+=	-fomit-frame-pointer
endif

ifdef CONFIG_MODVERSIONS
MODOPTS=-DMODVERSIONS -include $(KERNEL_PATH)/include/linux/modversions.h

GENKSYMS=	/sbin/genksyms
ifdef CONFIG_SMP
GENKSYMS+=	-p smp_
endif
endif

#
CC=	gcc
LD=	ld
STRIP=	strip
OBJCOPY=objcopy
NM=	nm

COPTS+=	-DAH_BYTE_ORDER=AH_LITTLE_ENDIAN
ifndef CONFIG_FRAME_POINTER
COPTS+=	-fomit-frame-pointer
endif

INCS= -I${LINUX}

CFLAGS= ${INCS} -D__KERNEL__ -DMODULE ${MODOPTS} ${COPTS}
#
# 2.4, 2.5, 2.6 handling.
# Wish we had proper conditionals to use here..
#
ifneq (${LINUX_VERSION}, 204)
KMODSUF=	ko
INCS+=		-I${KERNEL_PATH}/include/asm/mach-default
MODOPTS+=	-DKBUILD_BASENAME=${KMODNAME} -DKBUILD_MODNAME=${KMODNAME}
CLEANFILES+=	*.mod.c
else
KMODSUF=	o
endif
#

all: $(obj-m)

$(obj-m): $(obj-y)
	${LD} -o $@ -r ${LDFLAGS} $^

%.o: %.c
	${CC} -c -o $@ ${CFLAGS} $<
